@@ -2,7 +2,8 @@ from django.contrib.auth import get_user_model
 
 from ..api.exceptions import RestApiException
 from ..conf import conf
-from ..models import PhoneCode
+from ..models import \
+    PhoneCode
 from ..utils import SmsService
 
 User = get_user_model()
@@ -16,16 +17,23 @@ class AuthService(SmsService):
         super().__init__()
 
     def process(self):
-        generated_code = PhoneCode.objects.filter(
-            phone_number=self.phone_number, code=self.code
-        ).first()
+        generated_code = PhoneCode.objects.\
+            filter(phone_number=self.phone_number,
+                   code=self.code)\
+            .first()
 
         if generated_code is None:
             raise RestApiException(detail={"detail": conf.SMS_CODE_NOT_FOUND})
 
-        user, created = User.objects.get_or_create(
-            username=generated_code.phone_number, defaults={"is_active": True}
-        )
+        user = generated_code.owner
+        if user is None:
+            user, created = User.objects.get_or_create(
+                username=generated_code.phone_number,
+                defaults={"is_active": True}
+            )
+
+        user.username = generated_code.phone_number
+        user.save()
 
         generated_code.delete()
 
